@@ -137,6 +137,8 @@ bool Create::parseStream()
       mimeTypesSet = true;
     } else if ( key == "CACHEPOLICY" ) {
       HandlerHelper::parseCachePolicy( value, collection );
+    } else if ( key == "VIRTUAL" ) {
+      collection.setIsVirtual( value.toUInt() != 0 );
     } else {
       userDefAttrs << qMakePair( key, value );
     }
@@ -146,7 +148,7 @@ bool Create::parseStream()
   Transaction transaction( db );
 
   if ( !db->appendCollection( collection ) )
-    return failureResponse( "Could not create collection " + name.toLatin1() + " resourceId: " + QByteArray::number(resourceId));
+    return failureResponse( "Could not create collection " + name.toLocal8Bit() + " resourceId: " + QByteArray::number(resourceId));
 
   QStringList effectiveMimeTypes;
   if ( mimeTypesSet ) {
@@ -157,7 +159,7 @@ bool Create::parseStream()
       effectiveMimeTypes << mt.name();
   }
   if ( !db->appendMimeTypeForCollection( collection.id(), effectiveMimeTypes ) )
-    return failureResponse( "Unable to append mimetype for collection " + name.toLatin1() + " resourceId: " + QByteArray::number(resourceId) );
+    return failureResponse( "Unable to append mimetype for collection " + name.toLocal8Bit() + " resourceId: " + QByteArray::number(resourceId) );
 
   // store user defined attributes
   typedef QPair<QByteArray,QByteArray> QByteArrayPair;
