@@ -130,6 +130,11 @@ bool Modify::parseStream()
       if ( !db->moveCollection( collection, Collection::retrieveById( newParent ) ) )
         return failureResponse( "Unable to reparent collection" );
       changes.append( "PARENT" );
+    } else if ( type == "VIRTUAL" ) {
+      QString newValue;
+      pos = ImapParser::parseString( line, newValue, pos );
+      if ( newValue.toInt() != collection.isVirtual() )
+          return failureResponse( "Can't modify VIRTUAL collection flag" );
     } else if ( type == AKONADI_PARAM_REMOTEID ) {
       QString rid;
       pos = ImapParser::parseString( line, rid, pos );
@@ -226,3 +231,4 @@ bool Modify::parseStream()
 }
 
 #include "modify.moc"
+
