@@ -34,6 +34,7 @@
 #include "parthelper.h"
 #include "libs/protocol_p.h"
 #include "handler.h"
+#include "collectionqueryhelper.h"
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDir>
@@ -50,13 +51,14 @@
 #include <QtSql/QSqlError>
 #include <QtSql/QSqlField>
 #include <QtSql/QSqlQuery>
-#include "collectionqueryhelper.h"
 
 using namespace Akonadi;
 
 static QMutex sTransactionMutex;
-#define TRANSACTION_MUTEX_LOCK if ( m_database.driverName().startsWith( QLatin1String( "QSQLITE" ) ) ) sTransactionMutex.lock()
-#define TRANSACTION_MUTEX_UNLOCK if ( m_database.driverName().startsWith( QLatin1String( "QSQLITE" ) ) ) sTransactionMutex.unlock()
+bool DataStore::s_hasForeignKeyConstraints = false;
+
+#define TRANSACTION_MUTEX_LOCK if ( DbType::type( m_database ) == DbType::Sqlite ) sTransactionMutex.lock()
+#define TRANSACTION_MUTEX_UNLOCK if ( DbType::type( m_database ) == DbType::Sqlite ) sTransactionMutex.unlock()
 
 /***************************************************************************
  *   DataStore                                                           *
@@ -121,6 +123,8 @@ void Akonadi::DataStore::close()
 
 bool Akonadi::DataStore::init()
 {
+  Q_ASSERT( QThread::currentThread() == QCoreApplication::instance()->thread() );
+
   QString dbtemplate = QLatin1String(":akonadidb.xml");
 #ifdef Q_OS_WINCE
   dbtemplate = QLatin1String(":akonadidb-mobile.xml");
@@ -131,6 +135,7 @@ bool Akonadi::DataStore::init()
     akError() << initializer->errorMsg();
     return false;
   }
+  s_hasForeignKeyConstraints = initializer->hasForeignKeyConstraints();
 
   DbUpdater updater( m_database, QLatin1String( ":dbupdate.xml" ) );
   if ( !updater.run() )
@@ -259,18 +264,62 @@ bool DataStore::appendCollection( Collection &collection )
 
 bool Akonadi::DataStore::cleanupCollection(Collection &collection)
 {
+  if ( !s_hasForeignKeyConstraints )
+    return cleanupCollection_slow( collection );
+
+  // db will do most of the work for us, we just deal with notifications and external payload parts here
+  Q_ASSERT( s_hasForeignKeyConstraints );
+
+  // collect item deletion notifications
+  const PimItem::List items = collection.items();
+  const QByteArray resource = collection.resource().name().toLatin1();
+  Q_FOREACH ( const PimItem &item, items ) {
+
+    // generate the notification before actually removing the data
+    // TODO: we should try to get rid of this, requires client side changes to resources and Monitor though
+    mNotificationCollector->itemRemoved( item, collection, QString(), resource );
+  }
+
+  // remove all external payload parts
+  QueryBuilder qb( Part::tableName(), QueryBuilder::Select );
+  qb.addColumn( Part::dataFullColumnName() );
+  qb.addValueCondition( Part::externalFullColumnName(), Query::Equals, true );
+  qb.addValueCondition( Part::dataFullColumnName(), Query::IsNot, QVariant() );
+  qb.addJoin( QueryBuilder::InnerJoin, PimItem::tableName(), Part::pimItemIdFullColumnName(), PimItem::idFullColumnName() );
+  qb.addJoin( QueryBuilder::InnerJoin, Collection::tableName(), PimItem::collectionIdFullColumnName(), Collection::idFullColumnName() );
+  if ( !qb.exec() )
+    return false;
+
+  try {
+    while ( qb.query().next() )
+      PartHelper::removeFile( QString::fromUtf8( qb.query().value( 0 ).value<QByteArray>() ) );
+  } catch ( const PartHelperException &e ) {
+    akDebug() << e.what();
+    return false;
+  }
+
+  // delete the collection itself, referential actions will do the rest
+  mNotificationCollector->collectionRemoved( collection );
+  return collection.remove();
+}
+
+bool DataStore::cleanupCollection_slow(Collection& collection)
+{
+  Q_ASSERT( !s_hasForeignKeyConstraints );
+
   // delete the content
   const PimItem::List items = collection.items();
   const QByteArray resource = collection.resource().name().toLatin1();
   Q_FOREACH ( const PimItem &item, items ) {
 
     // generate the notification before actually removing the data
-    mNotificationCollector->itemRemoved( item, collection, QString(), resource ); // TODO: make mimetype available as part as an item bulk query
+    mNotificationCollector->itemRemoved( item, collection, QString(), resource );
 
     if ( !item.clearFlags() ) // TODO: move out of loop and use only a single query
       return false;
     if ( !PartHelper::remove( Part::pimItemIdColumn(), item.id() ) ) // TODO: reduce to single query
       return false;
+
     if ( !PimItem::remove( PimItem::idColumn(), item.id() ) ) // TODO: move into single query
       return false;
 
