@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2007 Volker Krause <vkrause@kde.org>
+    Copyright (c) 2007 - 2012 Volker Krause <vkrause@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -18,11 +18,16 @@
 */
 
 #include "dbupdater.h"
+#include "dbtype.h"
 #include "entities.h"
 #include "akdebug.h"
+#include "akdbus.h"
 
+#include <QCoreApplication>
+#include <QDBusConnection>
 #include <QSqlQuery>
 #include <QSqlError>
+#include <QThread>
 
 #include <QDomDocument>
 #include <QFile>
@@ -35,6 +40,8 @@ DbUpdater::DbUpdater( const QSqlDatabase & database, const QString & filename )
 
 bool DbUpdater::run()
 {
+  Q_ASSERT( QThread::currentThread() == QCoreApplication::instance()->thread() );
+
   // TODO error handling
   Akonadi::SchemaVersion currentVersion = Akonadi::SchemaVersion::retrieveAll().first();
 
@@ -43,6 +50,12 @@ bool DbUpdater::run()
   if ( !parseUpdateSets( currentVersion.version(), updates ) )
     return false;
 
+  if ( updates.isEmpty() )
+    return true;
+  // indicate clients this might take a while
+  // we can ignore unregistration in error cases, that'll kill the server anyway
+  QDBusConnection::sessionBus().registerService( AkDBus::serviceName(AkDBus::UpgradeIndicator) );
+
   // QMap is sorted, so we should be replaying the changes in correct order
   for ( QMap<int, UpdateSet>::ConstIterator it = updates.constBegin(); it != updates.constEnd(); ++it ) {
     Q_ASSERT( it.key() > currentVersion.version() );
@@ -74,6 +87,7 @@ bool DbUpdater::run()
     }
   }
 
+  QDBusConnection::sessionBus().unregisterService( AkDBus::serviceName(AkDBus::UpgradeIndicator) );
   return true;
 }
 
@@ -149,14 +163,18 @@ bool DbUpdater::updateApplicable( const QString &backends ) const
   const QStringList matchingBackends = backends.split( QLatin1Char( ',' ) );
 
   QString currentBackend;
-  if ( m_database.driverName() == QLatin1String( "QMYSQL" ) )
-    currentBackend = QLatin1String( "mysql" );
-  else if ( m_database.driverName() == QLatin1String( "QPSQL" ) )
-    currentBackend = QLatin1String( "psql" );
-  else if ( m_database.driverName().startsWith( QLatin1String( "QSQLITE" ) ) ) // QSQLITE or QSQLITE3
-    currentBackend = QLatin1String( "sqlite" );
-  else if ( m_database.driverName() == QLatin1String( "QODBC" ) )
-    currentBackend = QLatin1String( "odbc" );
+  switch ( DbType::type( m_database ) ) {
+    case DbType::MySQL:
+      currentBackend = QLatin1String( "mysql" ); break;
+    case DbType::PostgreSQL:
+      currentBackend = QLatin1String( "psql" ); break;
+    case DbType::Sqlite:
+      currentBackend = QLatin1String( "sqlite" ); break;
+    case DbType::Virtuoso:
+      currentBackend = QLatin1String( "odbc" ); break;
+    case DbType::Unknown:
+      return false;
+  }
 
   return matchingBackends.contains( currentBackend );
 }
