@@ -24,7 +24,6 @@ class QString;
 class QSqlQuery;
 
 namespace Akonadi {
-namespace Server {
 
 /**
  * A per-thread cache (should be per session, but that'S the same for us) prepared
@@ -40,13 +39,8 @@ namespace QueryCache
 
   /// Insert @p query into the cache for @p queryStatement.
   void insert( const QString &queryStatement, const QSqlQuery &query );
+};
 
-  /// Clears all queries from current thread
-  void clear();
-
-} // namespace QueryCache
-
-} // namespace Server
-} // namespace Akonadi
+}
 
 #endif // AKONADI_QUERYCACHE_H
